************
zfit physics
************

.. image:: https://scikit-hep.org/assets/images/Scikit--HEP-Affiliated-blue.svg
   :target: https://scikit-hep.org

.. image:: https://img.shields.io/pypi/v/zfit_physics.svg
   :target: https://pypi.python.org/pypi/zfit_physics



|zfit_logo|


.. |zfit_logo| image:: docs/images/zfit-fin_400x168.png
   :target: https://github.com/zfit/zfit
   :alt: zfit logo

Tools and models to extend `zfit <https://github.com/zfit/zfit>`_.
The structure of this package is still in flow, so before opening any PR
you may want to open an issue to discuss how your proposed functionality will fit into `zfit-physics`.

It is currently under heavy development. Use it to test currently experimental
features. It offers a similar structure are zfit and will in the future be
simply integrated into the zfit namespace (given that zfit-physics is installed).

What's new
=============

Check the `changelog <CHANGELOG.rst>`_ for recent changes.

Installing
==========


zfit-physics is available on pip. If possible, use a conda or virtual environment and do:


.. code-block:: console

    $ pip install zfit-physics


For the newest development version, you can install the version from git with

.. code-block:: console

   $ pip install git+https://github.com/zfit/zfit-physics

Contact
=======

You can contact us directly:
 - via e-mail: zfit@physik.uzh.ch
 - join our `Gitter channel <https://gitter.im/zfit/zfit>`_

Contributors
============
